function [A,t] = Gauss(dt,T)
%function [A,t] = Gauss(dt,T)
%
%	dt - sample interval
%	T - dominant period
%
%	Returns
%	A - Gaussian waveform
%	t - time series for waveform which will be -T:dt:T
%

%npts = T/dt;
t = -T:dt:T;
a = 10*(1/T)^2;
A = exp(-a*t.^2);
